@@ -1,4 +1,3 @@
-#!/usr/bin/env python3.10
 """
 NAME:    Onboardme.ide_setup
 DESC:    install vim, neovim, and fonts
@@ -13,7 +12,7 @@ from pathlib import Path
 import wget
 
 # custom libs
-from .console_logging import print_header, print_msg
+from .console_logging import print_header, print_sub_header, print_msg
 from .subproc import subproc
 from .env_config import HOME_DIR, OS
 
@@ -26,11 +25,10 @@ def vim_setup():
     """
     print_header('[b]vim-plug[/b] and [green][i]Vim[/i][/green] plugins '
                  'installation [dim]and[/dim] upgrades')
-    print('')
 
     # trick to not run youcompleteme init every single time
     init_ycm = False
-    ycm_dir = path.join(HOME_DIR, '.vim/plugged/YouCompleteMe/install.sh')
+    ycm_dir = path.join(HOME_DIR, '.vim/plugged/YouCompleteMe')
     if not path.exists(ycm_dir):
         init_ycm = True
 
@@ -47,11 +45,11 @@ def vim_setup():
     # updates all currently installed plugins
     subproc(['vim +PlugInstall +PlugUpgrade +PlugUpdate +qall!'],
             quiet=True)
-    print_msg('[i][dim]Vim Plugins installed.')
+    print_sub_header('Vim Plugins installed.')
 
     if init_ycm:
         # This is for you complete me, which is a python completion module
-        subproc(ycm_dir)
+        subproc(["chmod +x install.py", "./install.py"], cwd=ycm_dir)
 
     return True
 
@@ -69,33 +67,40 @@ def neovim_setup():
     """
     print_header('[b]packer[/b] and [green][i]NeoVim[/i][/green] plugins '
                  'installation [dim]and[/dim] upgrades')
-    print('')
 
     # updates all currently installed plugins
     commands = ["nvim --headless +PackerInstall",
                 "nvim --headless +PackerSync"]
     subproc(commands)
 
-    print_msg('[i][dim]NeoVim Plugins installed.')
+    print_sub_header('NeoVim Plugins installed.')
 
     return True
 
 
 def font_setup():
     """
-    Clones nerd-fonts repo and does a sparse checkout on only mononoki and
-    hack fonts. Also removes 70-no-bitmaps.conf and links 70-yes-bitmaps.conf
+    On macOS:
+      taps a brew cask and installs mononoki and hack fonts
+    On Linux:
+      Clones nerd-fonts repo and does a sparse checkout on only mononoki and
+      hack fonts. Also removes 70-no-bitmaps.conf and links 70-yes-bitmaps.conf
 
-    Then runs install.sh from nerd-fonts repo
-
-    ripped out of setup.sh recently:
-        # we do this for Debian, to download custom fonts during onboardme
-        if [[ "$OS" == *"Linux"* ]]; then
-            mkdir -p ~/.local/share/fonts
-        fi
+      Then runs install.sh from nerd-fonts repo
     """
+    print_header('📝 [i]font[/i] installations')
+
+    if 'Darwin' in OS:
+        # tap special cask for various terminal fonts
+        subproc(["brew tap homebrew/cask-fonts",
+                 "brew install --cask font-mononoki",
+                 "brew install --cask font-hack-nerd-font"])
+        print_sub_header("Fonts installed/upgraded.")
+
     if 'Linux' in OS:
-        print_header('📝 [i]font[/i] installations')
+        # not sure if needed anymore
+        # mkdir -p ~/.local/share/fonts
+
         fonts_dir = f'{HOME_DIR}/repos/nerd-fonts'
 
         # do a shallow clone of the repo
@@ -135,6 +140,4 @@ def font_setup():
 
         print_msg('[i][dim]The fonts should be installed, however, you have ' +
                   'to set your terminal font to the new font. I rebooted too.')
-        return
-
     return
